==> libreoffice-fresh-sdk-24.8.4-2-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.js <==
var servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet =
[
    [ "XPropertySet", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "XComponent", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#a3ee2eab6ea072f036a4548a48b0ed454", null ],
    [ "XCloseable", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#a48f0cd21cc329df0f7ef4f7b257b84c9", null ],
    [ "XColumnLocate", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#a3ab7c5de117d58ea69c6cbe5881c86b1", null ],
    [ "XResultSet", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#aa05d9932574c38a1326a84efd1e137c4", null ],
    [ "XResultSetMetaDataSupplier", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#a38ca48caefefab32ba669f42d0475fec", null ],
    [ "XResultSetUpdate", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#aa3bf44c4602f0c185445d8a7b9caa848", null ],
    [ "XRow", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#a82ec0ceeb7cd231fcac3eb4bd430db17", null ],
    [ "XRowUpdate", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#ac13f58cbe1f21093ca86ac6b3e9f4132", null ],
    [ "XWarningsSupplier", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#a54fa40f6bb07d6391a9ffe1aca3aa608", null ],
    [ "CursorName", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#a149de8c27496a1249f2e2ccf89f02769", null ],
    [ "FetchDirection", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#a5f21e7b675501abba335f05029ca9698", null ],
    [ "FetchSize", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#a50859cae047f6fad1388342516c909a2", null ],
    [ "ResultSetConcurrency", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#a02ed4f21e8c5321ab8d1c82268096368", null ],
    [ "ResultSetType", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#a20f37658bb98643b426f7d7f2e440ccb", null ]
];

==> libreoffice-fresh-sdk-25.8.2-4-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.js <==
var servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet =
[
    [ "com::sun::star::beans::XPropertySet", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "com::sun::star::lang::XComponent", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#a3ee2eab6ea072f036a4548a48b0ed454", null ],
    [ "XCloseable", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#a48f0cd21cc329df0f7ef4f7b257b84c9", null ],
    [ "XColumnLocate", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#a3ab7c5de117d58ea69c6cbe5881c86b1", null ],
    [ "XResultSet", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#aa05d9932574c38a1326a84efd1e137c4", null ],
    [ "XResultSetMetaDataSupplier", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#a38ca48caefefab32ba669f42d0475fec", null ],
    [ "XResultSetUpdate", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#aa3bf44c4602f0c185445d8a7b9caa848", null ],
    [ "XRow", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#a82ec0ceeb7cd231fcac3eb4bd430db17", null ],
    [ "XRowUpdate", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#ac13f58cbe1f21093ca86ac6b3e9f4132", null ],
    [ "XWarningsSupplier", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#a54fa40f6bb07d6391a9ffe1aca3aa608", null ],
    [ "CursorName", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#a149de8c27496a1249f2e2ccf89f02769", null ],
    [ "FetchDirection", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#a5f21e7b675501abba335f05029ca9698", null ],
    [ "FetchSize", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#a50859cae047f6fad1388342516c909a2", null ],
    [ "ResultSetConcurrency", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#a02ed4f21e8c5321ab8d1c82268096368", null ],
    [ "ResultSetType", "servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html#a20f37658bb98643b426f7d7f2e440ccb", null ]
];
